@@ -1,5 +1,7 @@
+import pandas as pd
 import tensorflow as tf
 
+from rexify.models.callbacks import BruteForceCallback
 from rexify.models.ranking import RankingMixin
 from rexify.models.retrieval import RetrievalMixin
 
@@ -28,9 +30,7 @@ class Recommender(RetrievalMixin, RankingMixin):
     An optional Ranking model is also included, granted there are `ranking_features`.
 
     Args:
-        user_id (str): the user ID feature name
         user_dims (int): number possible values for the user ID feature
-        item_id (str): the item ID feature name
         item_dims (int): number possible values for the item ID feature
         embedding_dim (int): output dimension of the embedding layer
         feature_layers (list): number of neurons in each layer for the feature models
@@ -38,7 +38,7 @@ class Recommender(RetrievalMixin, RankingMixin):
 
     Examples:
         >>> from rexify.models import Recommender
-        >>> model = Recommender('user_id', 15, 'item_id', 15)
+        >>> model = Recommender()
         >>> model.compile()
 
         >>> import numpy as np
@@ -50,24 +50,23 @@ class Recommender(RetrievalMixin, RankingMixin):
 
     def __init__(
         self,
-        user_id: str,
         user_dims: int,
-        item_id: str,
         item_dims: int,
+        user_embeddings: pd.DataFrame,
+        item_embeddings: pd.DataFrame,
         embedding_dim: int = 32,
         feature_layers: list[int] = None,
         output_layers: list[int] = None,
         ranking_dims: int = 1,
         rating_features: list[str] = None,
         rating_layers: list[int] = None,
-        ranking_weights: dict[str, float] = None,
     ):
         RetrievalMixin.__init__(
             self,
-            user_id=user_id,
             user_dims=user_dims + 1,
-            item_id=item_id,
             item_dims=item_dims + 1,
+            user_embeddings=user_embeddings,
+            item_embeddings=item_embeddings,
             embedding_dim=embedding_dim,
             feature_layers=feature_layers,
             output_layers=output_layers,
@@ -78,25 +77,43 @@ class Recommender(RetrievalMixin, RankingMixin):
             n_dims=ranking_dims,
             rating_features=rating_features,
             layer_sizes=rating_layers,
-            weights=ranking_weights,
         )
 
     def compute_loss(self, inputs, training: bool = False) -> tf.Tensor:
         embeddings = self(inputs)  # Recommender inherits RetrievalMixin's call method
-        loss = self.retrieval_task(*embeddings)
+        loss = RetrievalMixin.get_loss(self, *embeddings)
         loss += RankingMixin.get_loss(self, *embeddings, inputs["event"])
         return loss
 
+    def fit(
+        self,
+        x: tf.data.Dataset,
+        batch_size: int = None,
+        epochs: int = 1,
+        callbacks: list[tf.keras.callbacks.Callback] = None,
+        validation_data=None,
+    ):
+
+        sample_query = list(x.batch(1).take(1))[0][
+            "query"
+        ]  # required to set index shapes
+        callbacks = (
+            [BruteForceCallback(sample_query)] if callbacks is None else callbacks
+        )
+
+        x = x.batch(batch_size) if batch_size else x
+
+        return super().fit(
+            x, epochs=epochs, validation_data=validation_data, callbacks=callbacks
+        )
+
     def get_config(self):
         return {
             "item_dims": self._item_dims,
             "user_dims": self._user_dims,
-            "user_id": self._user_id,
-            "item_id": self._item_id,
             "output_layers": self._output_layers,
             "feature_layers": self._feature_layers,
             "ranking_dims": self._ranking_dims,
             "rating_layers": self._rating_layers,
             "rating_features": self._rating_features,
-            "ranking_weights": self._ranking_weights,
         }
